.. _github-stats-3-0-1:

GitHub statistics for 3.0.1 (Oct 25, 2018)
==========================================

GitHub statistics for 2018/09/18 (tag: v3.0.0) - 2018/10/25

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 31 issues and merged 127 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/37?closed=1>`__

The following 23 authors contributed 227 commits.

* Abhinuv Nitin Pitale
* Antony Lee
* Anubhav Shrimal
* Ben Root
* Colin
* Daniele Nicolodi
* David Haberthür
* David Stansby
* Elan Ernest
* Elliott Sales de Andrade
* Eric Firing
* ImportanceOfBeingErnest
* Jody Klymak
* Kai Muehlbauer
* Kevin Rose
* Marcel Martin
* MeeseeksMachine
* Nelle Varoquaux
* Nikita Kniazev
* Ryan May
* teresy
* Thomas A Caswell
* Tim Hoffmann

GitHub issues and pull requests:

Pull Requests (127):

* :ghpull:`12595`: Backport PR #12569 on branch v3.0.x (Don't confuse uintptr_t and Py_ssize_t.)
* :ghpull:`12623`: Backport PR #12285 on branch v3.0.x (FIX: Don't apply tight_layout if axes collapse)
* :ghpull:`12285`: FIX: Don't apply tight_layout if axes collapse
* :ghpull:`12622`: FIX: flake8errors 3.0.x mergeup
* :ghpull:`12619`: Backport PR #12548 on branch v3.0.x (undef _XOPEN_SOURCE breaks the build in AIX)
* :ghpull:`12621`: Backport PR #12607 on branch v3.0.x (STY: fix whitespace and escaping)
* :ghpull:`12616`: Backport PR #12615 on branch v3.0.x (Fix travis OSX build)
* :ghpull:`12594`: Backport PR #12572 on branch v3.0.x (Fix singleton hist labels)
* :ghpull:`12615`: Fix travis OSX build
* :ghpull:`12607`: STY: fix whitespace and escaping
* :ghpull:`12605`: Backport PR #12603 on branch v3.0.x (FIX: don't import macosx to check if eventloop running)
* :ghpull:`12604`: FIX: over-ride 'copy' on RcParams
* :ghpull:`12603`: FIX: don't import macosx to check if eventloop running
* :ghpull:`12602`: Backport PR #12599 on branch v3.0.x (Fix formatting of docstring)
* :ghpull:`12599`: Fix formatting of docstring
* :ghpull:`12593`: Backport PR #12581 on branch v3.0.x (Fix hist() error message)
* :ghpull:`12569`: Don't confuse uintptr_t and Py_ssize_t.
* :ghpull:`12572`: Fix singleton hist labels
* :ghpull:`12581`: Fix hist() error message
* :ghpull:`12575`: Backport PR #12573 on branch v3.0.x (BUG: mplot3d: Don't crash if azim or elev are non-integral)
* :ghpull:`12558`: Backport PR #12555 on branch v3.0.x (Clarify horizontalalignment and verticalalignment in suptitle)
* :ghpull:`12544`: Backport PR #12159 on branch v3.0.x (FIX: colorbar re-check norm before draw for autolabels)
* :ghpull:`12159`: FIX: colorbar re-check norm before draw for autolabels
* :ghpull:`12540`: Backport PR #12501 on branch v3.0.x (Rectified plot error)
* :ghpull:`12531`: Backport PR #12431 on branch v3.0.x (FIX: allow single-string color for scatter)
* :ghpull:`12431`: FIX: allow single-string color for scatter
* :ghpull:`12529`: Backport PR #12216 on branch v3.0.x (Doc: Fix search for sphinx >=1.8)
* :ghpull:`12527`: Backport PR #12461 on branch v3.0.x (FIX: make add_lines work with new colorbar)
* :ghpull:`12461`: FIX: make add_lines work with new colorbar
* :ghpull:`12522`: Backport PR #12241 on branch v3.0.x (FIX: make unused spines invisible)
* :ghpull:`12241`: FIX: make unused spines invisible
* :ghpull:`12519`: Backport PR #12504 on branch v3.0.x (DOC: clarify min supported version wording)
* :ghpull:`12517`: Backport PR #12507 on branch v3.0.x (FIX: make minor ticks formatted with science formatter as well)
* :ghpull:`12507`: FIX: make minor ticks formatted with science formatter as well
* :ghpull:`12512`: Backport PR #12363 on branch v3.0.x
* :ghpull:`12511`: Backport PR #12366 on branch v2.2.x (TST: Update test images for new Ghostscript.)
* :ghpull:`12509`: Backport PR #12478 on branch v3.0.x (MAINT: numpy deprecates asscalar in 1.16)
* :ghpull:`12363`: FIX: errors in get_position changes
* :ghpull:`12497`: Backport PR #12495 on branch v3.0.x (Fix duplicate condition in pathpatch3d example)
* :ghpull:`12490`: Backport PR #12489 on branch v3.0.x (Fix typo in documentation of ylim)
* :ghpull:`12485`: Fix font_manager.OSXInstalledFonts()
* :ghpull:`12484`: Backport PR #12448 on branch v3.0.x (Don't error if some font directories are not readable.)
* :ghpull:`12421`: Backport PR #12360 on branch v3.0.x (Replace axes_grid by axes_grid1 in test)
* :ghpull:`12448`: Don't error if some font directories are not readable.
* :ghpull:`12471`: Backport PR #12468 on branch v3.0.x (Fix ``set_ylim`` unit handling)
* :ghpull:`12475`: Backport PR #12469 on branch v3.0.x (Clarify documentation of offsetbox.AnchoredText's prop kw argument)
* :ghpull:`12468`: Fix ``set_ylim`` unit handling
* :ghpull:`12464`: Backport PR #12457 on branch v3.0.x (Fix tutorial typos.)
* :ghpull:`12432`: Backport PR #12277: FIX: datetime64 now recognized if in a list
* :ghpull:`12277`: FIX: datetime64 now recognized if in a list
* :ghpull:`12426`: Backport PR #12293 on branch v3.0.x (Make pyplot more tolerant wrt. 3rd-party subclasses.)
* :ghpull:`12293`: Make pyplot more tolerant wrt. 3rd-party subclasses.
* :ghpull:`12360`: Replace axes_grid by axes_grid1 in test
* :ghpull:`12412`: Backport PR #12394 on branch v3.0.x (DOC: fix CL tutorial to give same output from saved file and example)
* :ghpull:`12410`: Backport PR #12408 on branch v3.0.x (Don't crash on invalid registry font entries on Windows.)
* :ghpull:`12411`: Backport PR #12366 on branch v3.0.0-doc (TST: Update test images for new Ghostscript.)
* :ghpull:`12408`: Don't crash on invalid registry font entries on Windows.
* :ghpull:`12403`: Backport PR #12149 on branch v3.0.x (Mathtext tutorial fixes)
* :ghpull:`12400`: Backport PR #12257 on branch v3.0.x (Document standard backends in matplotlib.use())
* :ghpull:`12257`: Document standard backends in matplotlib.use()
* :ghpull:`12399`: Backport PR #12383 on branch v3.0.x (Revert change of parameter name in annotate())
* :ghpull:`12383`: Revert change of parameter name in annotate()
* :ghpull:`12390`: Backport PR #12385 on branch v3.0.x (CI: Added Appveyor Python 3.7 build)
* :ghpull:`12385`: CI: Added Appveyor Python 3.7 build
* :ghpull:`12381`: Backport PR #12353 on branch v3.0.x (Doc: clarify default parameters in scatter docs)
* :ghpull:`12378`: Backport PR #12366 on branch v3.0.x (TST: Update test images for new Ghostscript.)
* :ghpull:`12375`: Backport PR #11648 on branch v3.0.x (FIX: colorbar placement in constrained layout)
* :ghpull:`11648`: FIX: colorbar placement in constrained layout
* :ghpull:`12350`: Backport PR #12214 on branch v3.0.x
* :ghpull:`12348`: Backport PR #12347 on branch v3.0.x (DOC: add_child_axes to axes_api.rst)
* :ghpull:`12214`: Improve docstring of Annotation
* :ghpull:`12344`: Backport PR #12321 on branch v3.0.x (maint: setupext.py for freetype had a Catch case for missing ft2build.h)
* :ghpull:`12342`: Backport PR #12334 on branch v3.0.x (Improve selection of inset indicator connectors.)
* :ghpull:`12334`: Improve selection of inset indicator connectors.
* :ghpull:`12339`: Backport PR #12297 on branch v3.0.x (Remove some pytest parameterising warnings)
* :ghpull:`12338`: Backport PR #12268 on branch v3.0.x (FIX: remove unnecessary ``self`` in ``super_``-calls, fixes #12265)
* :ghpull:`12336`: Backport PR #12212 on branch v3.0.x (font_manager: Fixed problems with Path(...).suffix)
* :ghpull:`12268`: FIX: remove unnecessary ``self`` in ``super_``-calls, fixes #12265
* :ghpull:`12212`: font_manager: Fixed problems with Path(...).suffix
* :ghpull:`12331`: Backport PR #12322 on branch v3.0.x (Fix the docs build.)
* :ghpull:`12327`: Backport PR #12326 on branch v3.0.x (fixed minor spelling error in docstring)
* :ghpull:`12320`: Backport PR #12319 on branch v3.0.x (Fix Travis 3.6 builds)
* :ghpull:`12315`: Backport PR #12313 on branch v3.0.x (BUG: Fix typo in view_limits() for MultipleLocator)
* :ghpull:`12313`: BUG: Fix typo in view_limits() for MultipleLocator
* :ghpull:`12305`: Backport PR #12274 on branch v3.0.x (MNT: put back ``_hold`` as read-only attribute on AxesBase)
* :ghpull:`12274`: MNT: put back ``_hold`` as read-only attribute on AxesBase
* :ghpull:`12303`: Backport PR #12163 on branch v3.0.x (TST: Defer loading Qt framework until test is run.)
* :ghpull:`12299`: Backport PR #12294 on branch v3.0.x (Fix expand_dims warnings in triinterpolate)
* :ghpull:`12163`: TST: Defer loading Qt framework until test is run.
* :ghpull:`12301`: Ghostscript 9.0 requirement revisited
* :ghpull:`12294`: Fix expand_dims warnings in triinterpolate
* :ghpull:`12297`: Remove some pytest parameterising warnings
* :ghpull:`12295`: Backport PR #12261 on branch v3.0.x (FIX:  parasite axis2 demo)
* :ghpull:`12289`: Backport PR #12278 on branch v3.0.x (Document inheriting docstrings)
* :ghpull:`12287`: Backport PR #12262 on branch v3.0.x (Simplify empty-rasterized pdf test.)
* :ghpull:`12280`: Backport PR #12269 on branch v3.0.x (Add some param docs to BlockingInput methods)
* :ghpull:`12266`: Backport PR #12254 on branch v3.0.x (Improve docstrings of Animations)
* :ghpull:`12262`: Simplify empty-rasterized pdf test.
* :ghpull:`12254`: Improve docstrings of Animations
* :ghpull:`12263`: Backport PR #12258 on branch v3.0.x (Fix CSS for module-level data)
* :ghpull:`12250`: Backport PR #12209 on branch v3.0.x (Doc: Sort named colors example by palette)
* :ghpull:`12248`: Backport PR #12237 on branch v3.0.x (Use (float, float) as parameter type for 2D positions in docstrings)
* :ghpull:`12240`: Backport PR #12236 on branch v3.0.x
* :ghpull:`12237`: Use (float, float) as parameter type for 2D positions in docstrings
* :ghpull:`12242`: Backport PR #12238 on branch v3.0.x (Typo in docs)
* :ghpull:`12236`: Make boilerplate-generated pyplot.py flake8 compliant
* :ghpull:`12234`: Backport PR #12228 on branch v3.0.x (Fix trivial typo in docs.)
* :ghpull:`12230`: Backport PR #12213 on branch v3.0.x (Change win32InstalledFonts return value)
* :ghpull:`12213`: Change win32InstalledFonts return value
* :ghpull:`12223`: Backport PR #11688 on branch v3.0.x (Don't draw axis (spines, ticks, labels) twice when using parasite axes.)
* :ghpull:`12224`: Backport PR #12207 on branch v3.0.x (FIX: dont' check for interactive framework if none required)
* :ghpull:`12207`: FIX: don't check for interactive framework if none required
* :ghpull:`11688`: Don't draw axis (spines, ticks, labels) twice when using parasite axes.
* :ghpull:`12205`: Backport PR #12186 on branch v3.0.x (DOC: fix API note about get_tightbbox)
* :ghpull:`12204`: Backport PR #12203 on branch v3.0.x (Document legend best slowness)
* :ghpull:`12203`: Document legend's slowness when "best" location is used
* :ghpull:`12194`: Backport PR #12164 on branch v3.0.x (Fix Annotation.contains.)
* :ghpull:`12193`: Backport PR #12177 on branch v3.0.x (FIX: remove cwd from mac font path search)
* :ghpull:`12164`: Fix Annotation.contains.
* :ghpull:`12177`: FIX: remove cwd from mac font path search
* :ghpull:`12185`: Backport PR #12183 on branch v3.0.x (Doc: Don't use Sphinx 1.8)
* :ghpull:`12183`: Doc: Don't use Sphinx 1.8
* :ghpull:`12172`: Backport PR #12157 on branch v3.0.x (Properly declare the interactive framework for the qt4foo backends.)
* :ghpull:`12167`: Backport PR #12166 on branch v3.0.x (Document preference order for backend auto selection)
* :ghpull:`12166`: Document preference order for backend auto selection
* :ghpull:`12157`: Properly declare the interactive framework for the qt4foo backends.
* :ghpull:`12153`: Backport PR #12148 on branch v3.0.x (BLD: pragmatic fix for building basic_unit example on py37)

Issues (31):

* :ghissue:`12626`: AttributeError: module 'matplotlib' has no attribute 'artist'
* :ghissue:`12613`: transiently linked interactivity of unshared pair of axes generated with make_axes_locatable
* :ghissue:`12601`: Can't import matplotlib
* :ghissue:`12580`: Incorrect hist error message with bad color size
* :ghissue:`12567`: Calling pyplot.show() with TkAgg backend on x86 machine raises OverflowError.
* :ghissue:`12556`: Matplotlib 3.0.0 import hangs in clean environment
* :ghissue:`12550`: colorbar resizes in animation
* :ghissue:`12155`: Incorrect placement of Colorbar ticks using LogNorm
* :ghissue:`12438`: Scatter doesn't accept a list of strings as color spec.
* :ghissue:`12429`: scatter() does not accept gray strings anymore
* :ghissue:`12458`: add_lines misses lines for matplotlib.colorbar.ColorbarBase
* :ghissue:`12239`: 3d axes are collapsed by tight_layout
* :ghissue:`12488`: inconsistent colorbar tick labels for LogNorm
* :ghissue:`12515`: pyplot.step broken in 3.0.0?
* :ghissue:`12355`: Error for bbox_inches='tight' in savefig with make_axes_locatable
* :ghissue:`12505`: ImageGrid in 3.0
* :ghissue:`12291`: Importing pyplot crashes on macOS due to missing fontlist-v300.json and then Permission denied: '/opt/local/share/fonts'
* :ghissue:`12288`: New function signatures in pyplot break Cartopy
* :ghissue:`12445`: Error on colorbar
* :ghissue:`12446`: Polar Contour - float() argument must be a string or a number, not 'AxesParasiteParasiteAuxTrans'
* :ghissue:`12271`: error with errorbar with datetime64
* :ghissue:`12405`: plt.stackplot() does not work with 3.0.0
* :ghissue:`12406`: Bug with font finding, and here is my fix as well.
* :ghissue:`12325`: Annotation change from "s" to "text" in 3.0- documentation
* :ghissue:`11641`: constrained_layout and colorbar for a subset of axes
* :ghissue:`12352`: TeX rendering broken on master with windows
* :ghissue:`12354`: Too many levels of symbolic links
* :ghissue:`12265`: ParasiteAxesAuxTrans  pcolor/pcolormesh and contour/contourf broken
* :ghissue:`12173`: Cannot import pyplot
* :ghissue:`12120`: Default legend behavior (loc='best') very slow for large amounts of data.
* :ghissue:`12176`: import pyplot on MacOS without font cache will search entire subtree of current dir
